# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import agent_common_pb2 as agent__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61gent_service.proto\x12\x19\x61rmonik.api.grpc.v1.agent\x1a\x12\x61gent_common.proto2\x8d\x07\n\x05\x41gent\x12h\n\nCreateTask\x12,.armonik.api.grpc.v1.agent.CreateTaskRequest\x1a*.armonik.api.grpc.v1.agent.CreateTaskReply(\x01\x12\x8c\x01\n\x15\x43reateResultsMetaData\x12\x37.armonik.api.grpc.v1.agent.CreateResultsMetaDataRequest\x1a\x38.armonik.api.grpc.v1.agent.CreateResultsMetaDataResponse\"\x00\x12t\n\rCreateResults\x12/.armonik.api.grpc.v1.agent.CreateResultsRequest\x1a\x30.armonik.api.grpc.v1.agent.CreateResultsResponse\"\x00\x12}\n\x10NotifyResultData\x12\x32.armonik.api.grpc.v1.agent.NotifyResultDataRequest\x1a\x33.armonik.api.grpc.v1.agent.NotifyResultDataResponse\"\x00\x12n\n\x0bSubmitTasks\x12-.armonik.api.grpc.v1.agent.SubmitTasksRequest\x1a..armonik.api.grpc.v1.agent.SubmitTasksResponse\"\x00\x12\x62\n\x0fGetResourceData\x12&.armonik.api.grpc.v1.agent.DataRequest\x1a\'.armonik.api.grpc.v1.agent.DataResponse\x12`\n\rGetCommonData\x12&.armonik.api.grpc.v1.agent.DataRequest\x1a\'.armonik.api.grpc.v1.agent.DataResponse\x12`\n\rGetDirectData\x12&.armonik.api.grpc.v1.agent.DataRequest\x1a\'.armonik.api.grpc.v1.agent.DataResponseB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Agent'
  _globals['_AGENT']._serialized_start=71
  _globals['_AGENT']._serialized_end=980
# @@protoc_insertion_point(module_scope)
