# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: partitions_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import partitions_fields_pb2 as partitions__fields__pb2
from . import partitions_filters_pb2 as partitions__filters__pb2
from . import sort_direction_pb2 as sort__direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17partitions_common.proto\x12\x1e\x61rmonik.api.grpc.v1.partitions\x1a\x17partitions_fields.proto\x1a\x18partitions_filters.proto\x1a\x14sort_direction.proto\"\xa8\x02\n\x0cPartitionRaw\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1c\n\x14parent_partition_ids\x18\x02 \x03(\t\x12\x14\n\x0cpod_reserved\x18\x03 \x01(\x03\x12\x0f\n\x07pod_max\x18\x04 \x01(\x03\x12]\n\x11pod_configuration\x18\x07 \x03(\x0b\x32\x42.armonik.api.grpc.v1.partitions.PartitionRaw.PodConfigurationEntry\x12\x1d\n\x15preemption_percentage\x18\x05 \x01(\x03\x12\x10\n\x08priority\x18\x06 \x01(\x03\x1a\x37\n\x15PodConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x02\n\x15ListPartitionsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x38\n\x07\x66ilters\x18\x03 \x01(\x0b\x32\'.armonik.api.grpc.v1.partitions.Filters\x12H\n\x04sort\x18\x04 \x01(\x0b\x32:.armonik.api.grpc.v1.partitions.ListPartitionsRequest.Sort\x1a\x8b\x01\n\x04Sort\x12=\n\x05\x66ield\x18\x01 \x01(\x0b\x32..armonik.api.grpc.v1.partitions.PartitionField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"\x8a\x01\n\x16ListPartitionsResponse\x12@\n\npartitions\x18\x01 \x03(\x0b\x32,.armonik.api.grpc.v1.partitions.PartitionRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"!\n\x13GetPartitionRequest\x12\n\n\x02id\x18\x01 \x01(\t\"W\n\x14GetPartitionResponse\x12?\n\tpartition\x18\x01 \x01(\x0b\x32,.armonik.api.grpc.v1.partitions.PartitionRawB!\xaa\x02\x1e\x41rmoniK.Api.gRPC.V1.Partitionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'partitions_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\036ArmoniK.Api.gRPC.V1.Partitions'
  _PARTITIONRAW_PODCONFIGURATIONENTRY._options = None
  _PARTITIONRAW_PODCONFIGURATIONENTRY._serialized_options = b'8\001'
  _globals['_PARTITIONRAW']._serialized_start=133
  _globals['_PARTITIONRAW']._serialized_end=429
  _globals['_PARTITIONRAW_PODCONFIGURATIONENTRY']._serialized_start=374
  _globals['_PARTITIONRAW_PODCONFIGURATIONENTRY']._serialized_end=429
  _globals['_LISTPARTITIONSREQUEST']._serialized_start=432
  _globals['_LISTPARTITIONSREQUEST']._serialized_end=762
  _globals['_LISTPARTITIONSREQUEST_SORT']._serialized_start=623
  _globals['_LISTPARTITIONSREQUEST_SORT']._serialized_end=762
  _globals['_LISTPARTITIONSRESPONSE']._serialized_start=765
  _globals['_LISTPARTITIONSRESPONSE']._serialized_end=903
  _globals['_GETPARTITIONREQUEST']._serialized_start=905
  _globals['_GETPARTITIONREQUEST']._serialized_end=938
  _globals['_GETPARTITIONRESPONSE']._serialized_start=940
  _globals['_GETPARTITIONRESPONSE']._serialized_end=1027
# @@protoc_insertion_point(module_scope)
