# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: health_checks_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import health_checks_common_pb2 as health__checks__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bhealth_checks_service.proto\x12!armonik.api.grpc.v1.health_checks\x1a\x1ahealth_checks_common.proto2\x95\x01\n\x13HealthChecksService\x12~\n\x0b\x43heckHealth\x12\x35.armonik.api.grpc.v1.health_checks.CheckHealthRequest\x1a\x36.armonik.api.grpc.v1.health_checks.CheckHealthResponse\"\x00\x42#\xaa\x02 ArmoniK.Api.gRPC.V1.HealthChecksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'health_checks_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002 ArmoniK.Api.gRPC.V1.HealthChecks'
  _globals['_HEALTHCHECKSSERVICE']._serialized_start=95
  _globals['_HEALTHCHECKSSERVICE']._serialized_end=244
# @@protoc_insertion_point(module_scope)
